==> haskell-chell-0.5.0.2-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell
version:              0.5.0.2
visibility:           public
id:                   chell-0.5.0.2-GG579AkMtQE2pDfYUDalXZ
key:                  chell-0.5.0.2-GG579AkMtQE2pDfYUDalXZ
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing.
    It natively supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.

category:             Testing
abi:                  6dbbbc29d2477149ead9798d4d226404
exposed:              True
exposed-modules:      Test.Chell
hidden-modules:       Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell
hs-libraries:         HSchell-0.5.0.2-GG579AkMtQE2pDfYUDalXZ
depends:
    ansi-terminal-1.0.2-2SdInZ2XzOpHxNy7zA9Y2f base-4.17.2.1
    bytestring-0.11.5.3 options-1.2.1.1-HnhFVP8cxCc6LCiax0zj9a
    patience-0.3-76KPiSxHJ2U3wboHHGuXu
    random-1.2.1.3-EDeqrsptr1q9TLFlKboGu1 template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html:         /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-0.5.0.2-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell
version:              0.5.0.2
visibility:           public
id:                   chell-0.5.0.2-8jvazWaGjxUC08WDOVfdZf
key:                  chell-0.5.0.2-8jvazWaGjxUC08WDOVfdZf
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing.
    It natively supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.

category:             Testing
abi:                  1ff815da4104a709b472958bf1d51ac8
exposed:              True
exposed-modules:      Test.Chell
hidden-modules:       Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell
hs-libraries:         HSchell-0.5.0.2-8jvazWaGjxUC08WDOVfdZf
depends:
    ansi-terminal-1.0.2-7NrSlZkI0QJFeJ1Fjfyc7F base-4.17.2.1
    bytestring-0.11.5.3 options-1.2.1.1-HnhFVP8cxCc6LCiax0zj9a
    patience-0.3-76KPiSxHJ2U3wboHHGuXu
    random-1.2.1.3-pmpDwx4KoPB7GM5T4cLqS template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html:         /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
